*****************************************************************************************************
*****************************************************************************************************
*****      The follwing codes replicate the Main Samples in "Financial Gatekeepers and   	    ***** 
*****        Investor Protection: Evidence from Criminal Background Checks"          	        ***** 
*****        by Kelvin K. F. Law and Lillian F. Mills (2019, Journal of Accounting Research)	***** 
*****                                    Version: March 8, 2019									***** 
*****************************************************************************************************
*****************************************************************************************************
*The following codes construct main advisor sample
*Read raw FINRA employment data 
	use "D:\Dropbox\19-03-08 JAR Replications\advisor\employment_combined.dta", clear
*Construct advisor-year panel
	keep individualid firmid begin end zip5
	gduplicates drop _all, force
	gsort individualid begin firmid 
	drop if begin==.
	gen begyear = year(begin)
	gen endyear = year(end)
	gen length = endyear - begyear + 1
	gen recordid = _n
	expand(length)
	gsort recordid
	by recordid: gen id = _n
	gen year = begyear + id - 1
	rename id tenure
	drop if year(end)<year & end!=. & year!=.
	drop begyear endyear length
	gduplicates drop _all, force
	gsort recordid year begin 
*Years in profession
	by individualid, sort: egen since = min(year)
	gen genexp = year - since + 1 if since>=1946
	gsort recordid year begin 
*Firm size
	preserve
	keep year firmid individualid 
	gduplicates drop year firmid individualid, force
	gen dum = 1
	gcollapse (sum) firmsize = dum, by(firmid year)
	tempfile temp1
	save "`temp1'", replace
	restore
	merge m:1 firmid year using "`temp1'"
	drop if _merge==2
	drop _merge
	gsort recordid year begin 
*Branch size
	preserve
	keep year firmid individualid zip5
	drop if zip5==.
	drop if firmid==.
	gduplicates drop year firmid individualid zip5, force
	gen dum = 1
	gcollapse (sum) branchsize = dum, by(firmid zip5 year)
	tempfile temp2
	save "`temp2'", replace
	restore
	merge m:1 firmid zip5 year using "`temp2'"
	drop if _merge==2
	drop _merge
	gsort recordid year begin 
*One advisor obs per year
	egen groupid = group(individualid year)
	sort groupid firmsize
	by groupid: gen id = _n
	by groupid: egen maxid = max(id)
	keep if maxid==id
	drop groupid maxid id
	gsort recordid year begin 
	gduplicates drop individualid year, force
*Gender
	merge m:1 individualid using "D:\Dropbox\19-03-08 JAR Replications\advisor\Individual ID gender data.dta"
	drop if _merge==2
	drop _merge
	gsort individualid year
*Basic information (e.g., names, exam, bar status)
	merge m:1 individualid using "D:\Dropbox\19-03-08 JAR Replications\advisor\basicinformation.dta"
	drop if _merge==2
	drop _merge
	gsort individualid year
*Criminal records
	gen individual_id = individualid 
	merge m:1 individualid using "D:\Dropbox\19-03-08 JAR Replications\advisor\All criminals.dta" 
	drop if _merge==2
	drop _merge
	replace criminal = 0 if criminal==.
	gsort individualid year
*Exclude financial advisors deregistered between 1971 and 2006
	merge m:1 individualid using "D:\Dropbox\19-03-08 JAR Replications\advisor\List of excluded advisors deregistered between 1971 and 2006.dta"
	drop if _merge==2
	drop _merge
	drop if excluded==1
	gsort individualid year
*Exclude not-in-scope financial advisors
	merge m:1 individualid using "D:\Dropbox\19-03-08 JAR Replications\advisor\Not in scope financial advisors.dta"
	drop if _merge==2
	drop _merge
	drop if notinscope==1
	gsort individualid year
	save "D:\Dropbox\19-03-08 JAR Replications\advisor\Main Advisor Sample.dta"
*****************************************************************************************************
*****************************************************************************************************
*The following codes construct main advisory firm sample
*Read raw FINRA advisory firm data 
	use "D:\Dropbox\19-03-08 JAR Replications\firm\basicInformation.dta", clear
	drop if bcscope==""
	gen firmid = firm_id
	gsort firmid
*Get number of advisors with criminal records per firm
	merge 1:1 firmid using "D:\Dropbox\19-03-08 JAR Replications\firm\Num advisor with criminal per firm.dta"
	drop if _merge==2
	drop _merge
	gen lnnumadvisor = ln(numadvisor)
	gen lnnumcriminal = ln(1+numcriminal)
*Small firm
	gen small = 0
	replace small = 1 if numadvisor<=150
	replace small = 1 if firmsize=="Small"
*Formation year
	gen formyear = substr(formeddate,-4,.)
	destring(formyear), replace
*Firm expelled
	gen cancel = 0
	replace cancel = 1 if strpos(sanctions_sanctiondetails_messag,"cancel")
	gen expel = 0
	replace expel = 1 if strpos(sanctions_sanctiondetails_messag,"expel")
	replace expel = 1 if expelleddate!=. & expel==0
	gen expel_or_cancel = 0
	replace expel_or_cancel = 1 if cancel==1
	replace expel_or_cancel = 1 if expel==1
*Corporation status
	gen corp = 0
	replace corp = 1 if firmtype=="Corporation"
*Zip code
	merge 1:1 firm_id using "D:\Dropbox\19-03-08 JAR Replications\firm\firmAddressDetails.dta"
	drop if _merge==2
	drop _merge
	gsort firmid
*Address
	merge 1:1 firm_id using "D:\Dropbox\19-03-08 JAR Replications\firm\iaFirmAddressDetails.dta", update
	drop if _merge==2
	drop _merge
	gsort firmid
	duplicates drop _all, force
*Registration
	merge 1:1 firm_id using "D:\Dropbox\19-03-08 JAR Replications\firm\registrations.dta"
	drop if _merge==2
	drop _merge
	replace mailingaddress_postalcode = officeaddress_postalcode if mailingaddress_postalcode=="" & officeaddress_postalcode!=""
	gsort firmid
*Branch location
	merge m:1 firm_id using "D:\Dropbox\19-03-08 JAR Replications\firm\Find location based on branch office.dta"
	drop if _merge==2
	drop _merge
	gsort firmid
*Zip code
	gen zip5 = substr(mailingaddress_postalcode,1,5)
	gen zip3 = substr(mailingaddress_postalcode,1,3)
	destring(zip3), replace force
	destring(zip5), replace force
	replace zip5 = branchoffice_zipcode if zip5==. & branchoffice_zipcode!=.
	rename zip5 zip
	rename state stateabbr
*State, County, and MSA FIPS
	merge m:1 zip using "D:\Dropbox\19-03-08 JAR Replications\firm\zipcode.dta", keepusing(x y city state statecode county msa)
	drop if _merge==2
	drop _merge
	gen statecounty = state*1000 + county
	gsort firmid
*City ID
	egen cityid = group(city)
*State ID
	egen formstate_id = group(formedstate)
*Control variables
	gen referral = 0
	replace referral = 1 if referotherbd=="N"
	gen affil = 0
	replace affil=1 if hasaffliation=="Y"
	foreach var in referral affil businesstypecount approvedstateregistrationcount{
		replace `var' = 0 if `var'==.
	}
	gen lnbusinesstypecount = ln(1+businesstypecount)
	gen lnstatereg = ln(1+approvedstateregistrationcount)
*Identify firms that hire advisors with pre-advisor criminal records
	merge 1:1 firmid using "D:\Dropbox\19-03-08 JAR Replications\firm\List of firm which hire advisor with pre-advisor criminal records.dta"
	drop if _merge==2
	drop _merge
	replace firmhire_preadvisor_criminal=0 if firmhire_preadvisor_criminal==.
	gsort firmid
*Identify the fraction of advisors with pre-advisor criminal records
	merge 1:1 firmid using "D:\Dropbox\19-03-08 JAR Replications\firm\Fraction of advisors with pre-advisor criminal records.dta"
	drop if _merge==2
	drop _merge
	gsort firmid
*SEC ADV form 2017 Data
	merge m:1 firmid using "D:\Dropbox\19-03-08 JAR Replications\firm\2017 Data cleaned.dta" 
	drop if _merge==2
	drop _merge
	gsort firmid
*Retail
	merge m:1 firmid using "D:\Dropbox\19-03-08 JAR Replications\firm\Identify retail investment advisers based on 2010-2017 data.dta"
	drop if _merge==2
	drop _merge
	gsort firmid
*Number of firm regulatory disclosure
	merge m:1 firm_id using "D:\Dropbox\19-03-08 JAR Replications\firm\Regulatory event per firm active only.dta"
	drop if _merge==2
	drop _merge
	replace disclosurecount = 0 if disclosurecount==.
	gen lndisclosurecount = ln(1+disclosurecount)
	gsort firmid
*High-risk brokerage
	gen regfirm_90 = 0
	replace regfirm_90 = 1 if disclosurecount>=9 & disclosurecount!=.
*Fee structure
	merge m:1 firmid using "D:\Dropbox\19-03-08 JAR Replications\firm\Identify fee structure.dta"
	drop if _merge==2
	drop _merge
	gsort firmid
*Number of accounts
	gen num_of_accounts = 0
	replace num_of_accounts = _5f_2_f if _5f_2_f!=.
	gen mil_num_of_accounts = num_of_accounts/1000000
*Missing variable indicator
	gen missing_indicator = 0
	replace missing_indicator = 1 if retail==.
	save "D:\Dropbox\19-03-08 JAR Replications\firm\Main Advisory Firm Sample.dta"
